package util

import (
	"context"
	"fmt"
	"time"
)

func IntervalTimer(ctx context.Context, lastRun time.Time, interval time.Duration, function func(ctx context.Context)) context.CancelFunc {
	childContext, cancelFunc := context.WithCancel(ctx)

	go func() {
		nextRun := lastRun.Add(interval)
		if nextRun.After(time.Now()) {
			fmt.Printf("Updating RSS feed every %s starting at %s\n", interval, nextRun)
			select {
			case <-childContext.Done():
				return
			case <-time.After(time.Until(nextRun)):
			}
		} else {
			fmt.Printf("Updating RSS feed every %s starting at %s\n", interval, time.Now())
		}
		ticker := time.NewTicker(interval)
		function(childContext)
		for {
			select {
			case <-childContext.Done():
				ticker.Stop()
				return
			case <-ticker.C:
				function(childContext)
			}
		}
	}()
	return cancelFunc
}
