package util

import (
	"fmt"
	"io"
)

type multiCloser struct {
	a io.Closer
	b io.Closer
}

func MultiCloser(a io.Closer, b io.Closer) io.Closer {
	return multiCloser{a, b}
}

func (c multiCloser) Close() error {
	errA := c.a.Close()
	errB := c.b.Close()
	if errA != nil && errB != nil {
		return fmt.Errorf("multiple errors: %w, %w", errA, errB)
	} else if errA != nil {
		return errA
	} else if errB != nil {
		return errB
	} else {
		return nil
	}
}
